==> obs-advanced-scene-switcher_1.29.2.orig.tar.gz: SceneSwitcher-1.29.2/lib/utils/plugin-state-helpers.hpp <==
#pragma once
#include <functional>
#include <obs.hpp>
#include <string>

namespace advss {

void SavePluginSettings(obs_data_t *);
EXPORT void LoadPluginSettings(obs_data_t *);

EXPORT void AddSaveStep(std::function<void(obs_data_t *)>);
EXPORT void AddLoadStep(std::function<void(obs_data_t *)>);
EXPORT void AddPostLoadStep(std::function<void()>);
EXPORT void AddIntervalResetStep(std::function<void()>);
EXPORT void RunPostLoadSteps();

EXPORT void AddPluginInitStep(std::function<void()>);
EXPORT void AddPluginPostLoadStep(std::function<void()>);
EXPORT void AddPluginCleanupStep(std::function<void()>);
void RunPluginInitSteps();
extern "C" EXPORT void RunPluginPostLoadSteps();
void RunPluginCleanupSteps();

EXPORT void StopPlugin();
EXPORT void StartPlugin();
EXPORT bool PluginIsRunning();
EXPORT int GetIntervalValue();
void AddStartStep(std::function<void()>);
void AddStopStep(std::function<void()>);
void RunStartSteps();
void RunStopSteps();
void RunIntervalResetSteps();

enum class NoMatchBehavior { NO_SWITCH = 0, SWITCH = 1, RANDOM_SWITCH = 2 };
EXPORT void SetPluginNoMatchBehavior(NoMatchBehavior);
EXPORT NoMatchBehavior GetPluginNoMatchBehavior();
EXPORT void SetNoMatchScene(const OBSWeakSource &);

EXPORT std::string ForegroundWindowTitle();
EXPORT std::string PreviousForegroundWindowTitle();

EXPORT bool SettingsWindowIsOpened();
EXPORT bool HighlightUIElementsEnabled();

EXPORT bool OBSIsShuttingDown();
EXPORT bool InitialLoadIsComplete();
EXPORT bool IsFirstInterval();
EXPORT bool IsFirstIntervalAfterStop();

} // namespace advss

==> obs-advanced-scene-switcher_1.31.0.orig.tar.gz: SceneSwitcher-1.31.0/lib/utils/plugin-state-helpers.hpp <==
#pragma once
#include <functional>
#include <obs.hpp>
#include <string>

namespace advss {

void SavePluginSettings(obs_data_t *);
EXPORT void LoadPluginSettings(obs_data_t *);

EXPORT void AddSaveStep(std::function<void(obs_data_t *)>);
EXPORT void AddLoadStep(std::function<void(obs_data_t *)>);
EXPORT void AddPostLoadStep(std::function<void()>);
EXPORT void AddIntervalResetStep(std::function<void()>);
EXPORT void RunPostLoadSteps();

EXPORT void AddPluginInitStep(std::function<void()>);
EXPORT void AddPluginPostLoadStep(std::function<void()>);
EXPORT void AddPluginCleanupStep(std::function<void()>);
void RunPluginInitSteps();
extern "C" EXPORT void RunPluginPostLoadSteps();
void RunPluginCleanupSteps();

EXPORT void StopPlugin();
EXPORT void StartPlugin();
EXPORT bool PluginIsRunning();
EXPORT int GetIntervalValue();
EXPORT void AddStartStep(std::function<void()>);
EXPORT void AddStopStep(std::function<void()>);
void RunStartSteps();
void RunStopSteps();
void RunIntervalResetSteps();

enum class NoMatchBehavior { NO_SWITCH = 0, SWITCH = 1, RANDOM_SWITCH = 2 };
EXPORT void SetPluginNoMatchBehavior(NoMatchBehavior);
EXPORT NoMatchBehavior GetPluginNoMatchBehavior();
EXPORT void SetNoMatchScene(const OBSWeakSource &);

EXPORT std::string ForegroundWindowTitle();
EXPORT std::string PreviousForegroundWindowTitle();

EXPORT bool SettingsWindowIsOpened();
EXPORT bool HighlightUIElementsEnabled();

EXPORT bool OBSIsShuttingDown();
EXPORT bool InitialLoadIsComplete();
EXPORT bool IsFirstInterval();
EXPORT bool IsFirstIntervalAfterStop();

} // namespace advss
